@rem = ' This is a perl script for NT and UNIX.
@echo off
goto endofperl
@rem ';
# -*- tab-width: 4 -*-

#---------------------------------------------------------------------------+
# Licensed Materials - Property of IBM
# Rational ClearCase
# Copyright IBM Corp. 1998, 2005. All Rights Reserved
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract
# with IBM Corp.
#---------------------------------------------------------------------------+

###########################################################################
# scrub_sync_logs.bat
# usage: sync_receive.bat - run with "-help" for detailed usage.
#
# This script is intended to be run periodically by the ClearCase
# Job Scheduler to scrub log files created by the MultiSite
# sync scripts - sync_export_list.bat and sync_receive.bat. It creates its own
# log files (and scrubs them, also).
#
# Normally the scheduler runs a task which invokes "cleanlogs.bat".
# cleanlogs.bat attempts to run "other_log_scrubber.pl", which then invokes
# this script, "scrub_sync_logs.bat" along with any other scrubbing tasks
# that may be defined.
#
# This script may also be executed interactively from the command line to
# force scrubbing to occur immediately.
###########################################################################

use strict;
use Getopt::Long;

use ClearCase::CurrentVersion;
sub dbgprint;  # predeclare, routine is in require file
sub qprint;    # predeclare

my $thisscript = $0;
if ($thisscript =~ m/(.*)(\.bat)$/) {
    $thisscript = $1;
}

my $pkg_name = 'scrub_sync_logs';
$CFG::verbose = ($ENV{TRACE_SUBSYS} && ($ENV{TRACE_SUBSYS} =~ m/$pkg_name/));
# force debugging msgs by uncommenting the following and setting to 1.....
#$CFG::verbose = 1;

$CFG::quietmode = 0;

# if 'verbose' mode is on, force the debug msgs to also print to STDERR by
# uncommenting this line (forces debug msgs to appear in the log file,
# may be useful if you're having problems with a scheduled job).
#$CFG::stderr_msgs = 1;

use Config;
my $arch = $^O ? $^O : $main::Config{archname};
$CFG::NT = (($arch =~ /^MSWin32/) || ($arch eq 'i386-win32')) ? 1 : 0;
$CFG::UNIX = ($CFG::NT ? 0 : 1);

# CLEARCASEHOME e.v. should always be set on NT when called by ccperlpp.pl,
# so exit if it's not set. On UNIX, assume /opt/rational/clearcase
# if EV is not set.
if ($CFG::UNIX) {  # UNIX - we shouldn't be here!
    die "This scrubber intended for Windows platforms only!";
    # UNIX has its own scrubber, but if desired, this could be modified
    # to run on UNIX, so leave the following lines in... and comment out
    # the "die" above to allow running on UNIX.
    my $producthome = &ClearCase::CurrentVersion::SetProductHomeEV;
    chdir $producthome;
    push(@INC, "$producthome/config/scheduler/tasks");
} else {
    my $producthome = $ENV{CLEARCASEHOME} or 
        die "CLEARCASEHOME env. variable not set\n";
    chdir $producthome;
    push(@INC, "$producthome\\config\\scheduler\\tasks");
    $thisscript = $pkg_name;
}
$CFG::including_script = $thisscript;

# set script version to test for mismatch against the syncmgr_common.pl version.
$CFG::MS_script_version = "7.0.0.0_syncmgr";

require 'syncmgr_common.pl';
require 5.8.6;

if (!$CFG::MScommon_version) {
    $CFG::MScommon_version = "(unknown older version)";
}

# check versions - syncmgr_common.pl should set $CFG::MScommon_version;
# if not set or unequal, indicates that an older/newer version is being
# included improperly.

if ($CFG::MScommon_version ne $CFG::MS_script_version) {
    die "Version mismatch between require file 'syncmgr_common.pl' " .
        "(version: ${CFG::MScommon_version}) and \n" .
        "the MultiSite script which includes it, 'scrub_sync_logs.bat' " .
        "(version: ${CFG::MS_script_version}).\n" . 
        "Ensure that old versions of the script/require file are not in use.\n";
}

$| = 1 if $CFG::verbose;

dbgprint "running in directory: ", DoCmd($CFG::workingdir_cmd);
dbgprint "running on architecture $arch\n";

###########################################################################
# main
#

my $usage = "$thisscript [-h] [-lo logdir] [-d days]\n";

my $helpmsg = <<ENDHELP;
=========================================================================
"scrub_sync_logs" is a scrubber to remove old logfiles generated by the 
MultiSite "sync_receive" and "sync_export_list" scripts, as well as the
logfiles generated by this script itself. 

It should be run periodically from the scheduler to free space used by the 
logs, but may also be run manually by an administrator if desired. Currently
the scrubber is intended for use on Windows platforms only.

The script contains default values for "-logdir" and "-days", so no arguments
are required if these values are satisfactory. A "-days" value is invalid if
less than 1.

The script looks for files in the log directory with a prefix of "recv-",
"send-", or "syncscrub-" and a "_log" suffix. Matching files older than the 
"days" logfile retention period are scrubbed.

Setting the environment variable TRACE_SUBSYS to "scrub_sync_logs" will turn
on internal debugging print statements (verbose mode).

$usage
Command line options:

    -help               Print this message and exit.

    -logdir directory   Specify directory to be scrubbed, in double quotes if
                        directory path contains spaces.
                        Default:
                        Windows:   {CLEARCASEHOME}\\var\\log

    -days days          The amount of time (in integer days) to keep sync logs.
                        Files with creation date older than 'days' will be 
                        removed.
                        Default: 14 days of logs will be retained.
=========================================================================
ENDHELP

# get command line options figured out...
dbgprint "ARGV: " . join(' ',@ARGV) . "\n";

my $logdir = '';
my $help = 0;
#$CFG::traceflg = 0;
my $days = 14;
my @SAVE_ARGV = @ARGV;

my $st = GetOptions("logdir=s" => \$logdir,
                    "help!" => \$help,
                    "days=i" => \$days);

if ($help) {
    qprint "$helpmsg\n";
    exit 1;
}

if (!$st) {
    qprint "ERROR: error getting command line options.\nUsage: $usage\n";
    exit 1;
}

if ($days < 1) {  # "days" value must be > 1
    qprint "ERROR: -days value must be > 1.\n";
    exit 1;
}

dbgprint "options:\n    logdir: $logdir\n" .
    "    days: $days days\n";

if (!$logdir) {     # if no logdir passed, use default
    $logdir = $CFG::logdir;
}

dbgprint "logdir is: $logdir\n";

if ($logdir && (!-e $logdir || !-d $logdir)) {
    die "Error: invalid log directory $logdir.";
}

if (!-w $logdir) {
    die "Error: Can't scrub - $logdir not writeable.";
}

chdir $logdir;
#print "running in logdir $logdir\n";

#
# Redirect STDERR to a uniquely named log file
#
my $logname = RedirectSTDERRtoLog ($logdir, 'syncscrub');

print STDERR "=========================================================\n" .
    "Starting MultiSite scrubbing from script '$thisscript' at " .
    MakeTimestamp() . "\n";

print STDERR "Actual arguments: " . join(' ',@SAVE_ARGV) . "\n";

print STDERR "options:\n    logdir: '$logdir'\n    days: '$days' days\n";

opendir (DIR, $logdir) or die "Can't open logdir $logdir: $!";

my $pname;
my $scrubcount = 0;

while(defined($pname = readdir DIR)) {
    my $age;
    if (-f $pname && ($pname =~ m/^(recv|send|syncscrub)-.*_log$/)) {
        $age = -M $pname;
        #print "$pname: $age\n";
        if ($age > $days) {
            if ((unlink "$pname") > 0) {  # status successful
                dbgprint "scrubbed $pname age: $age days\n";
                $scrubcount++;
            } else {
                dbgprint "failed to scrub $pname age: $age days\n";
                print STDERR "Unable to remove logfile $pname\n";
            }
        }
    }
}
closedir DIR;
print STDERR "End of MultiSite log scrubbing, $scrubcount files removed.\n";
print "End of MultiSite log scrubbing: $scrubcount files removed.\n";

__END__
:endofperl
ccperl -S ccperlpp.pl %0.bat %*
